==> EspoCRM-8.2.3.zip: EspoCRM-8.2.3/application/Espo/Core/Formula/Functions/RecordGroup/AttributeType.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM – Open Source CRM application.
 * Copyright (C) 2014-2024 Yurii Kuznietsov, Taras Machyshyn, Oleksii Avramenko
 * Website: https://www.espocrm.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\Core\Formula\Functions\RecordGroup;

use Espo\Core\Exceptions\Error;

use Espo\Core\Di;

class AttributeType extends \Espo\Core\Formula\Functions\AttributeType implements
    Di\EntityManagerAware
{
    use Di\EntityManagerSetter;

    public function process(\stdClass $item)
    {
        if (count($item->value) < 3) {
            throw new Error("record\\attribute: too few arguments.");
        }

        $entityType = $this->evaluate($item->value[0]);
        $id = $this->evaluate($item->value[1]);
        $attribute = $this->evaluate($item->value[2]);

        if (!$entityType) {
            throw new Error("Formula record\\attribute: Empty entityType.");
        }

        if (!$id) {
            return null;
        }

        if (!$attribute) {
            throw new Error("Formula record\\attribute: Empty attribute.");
        }

        $entity = $this->entityManager->getEntity($entityType, $id);

        if (!$entity) {
            return null;
        }

        return $this->attributeFetcher->fetch($entity, $attribute);
    }
}

==> EspoCRM-8.4.2.zip: EspoCRM-8.4.2/application/Espo/Core/Formula/Functions/RecordGroup/AttributeType.php <==
<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM – Open Source CRM application.
 * Copyright (C) 2014-2024 Yurii Kuznietsov, Taras Machyshyn, Oleksii Avramenko
 * Website: https://www.espocrm.com
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

namespace Espo\Core\Formula\Functions\RecordGroup;

use Espo\Core\Formula\Exceptions\Error;

use Espo\Core\Di;

class AttributeType extends \Espo\Core\Formula\Functions\AttributeType implements
    Di\EntityManagerAware
{
    use Di\EntityManagerSetter;

    public function process(\stdClass $item)
    {
        if (count($item->value) < 3) {
            throw new Error("record\\attribute: too few arguments.");
        }

        $entityType = $this->evaluate($item->value[0]);
        $id = $this->evaluate($item->value[1]);
        $attribute = $this->evaluate($item->value[2]);

        if (!$entityType) {
            throw new Error("Formula record\\attribute: Empty entityType.");
        }

        if (!$id) {
            return null;
        }

        if (!$attribute) {
            throw new Error("Formula record\\attribute: Empty attribute.");
        }

        $entity = $this->entityManager->getEntity($entityType, $id);

        if (!$entity) {
            return null;
        }

        return $this->attributeFetcher->fetch($entity, $attribute);
    }
}
